@@ -2,6 +2,7 @@ import json
 import os
 from enum import Enum
 from string import Template
+
 import requests as req
 from requests_toolbelt import MultipartEncoder
 
@@ -37,7 +38,7 @@ def __readTxt(subPath):
     path = os.path.abspath(os.path.join(os.getcwd(), "template"))
     print('当前目录:' + path)
 
-    f = open(path+'/%s' % subPath)
+    f = open(path + '/%s' % subPath)
     content = f.read()
     f.close()
     return content
@@ -229,51 +230,3 @@ def sendChatMsg(msgType: MSG_TYPE, title: str = None, content=None, bottons: lis
                 return [False, result.get('msg')]
         else:
             return [False, '发送异常']
-
-
-if __name__ == '__main__':
-#     '''
-#     文本消息
-    content = __buildMsg(msgType=MSG_TYPE.TEXT, content='文本消息')
-#     富文本消息
-#     content = __buildMsg(msgType=MSG_TYPE.RICH_TEXT, content=[
-#         {
-#             'tag': 'text',
-#             'text': '这是文本的内容  ',
-#         },
-#         {
-#             'tag': 'a',
-#             'text': '点我查看详情',
-#             'href': 'https://github.com/devzwy'
-#         },
-#         {
-#             'tag': 'at',
-#             'user_id': '01ao86c2-ed06-4a74-857b-707d5a506bea',
-#         }
-#     ])
-#
-#     卡片消息
-#     content = __buildMsg(msgType=MSG_TYPE.CARD, title='卡片消息', content='卡片消息内容', bottons=[
-#         {
-#             'bt_title': '测试按钮 :玫瑰:',
-#             'href': 'https://github.com/devzwy'
-#         }
-#     ])
-#     群名片
-#     content = __buildMsg(msgType=MSG_TYPE.GROUP_CARD,content='oc_f5b1a7eb27ae2c7b6adc2a74faf339ff')
-#
-#
-#     https://open.feishu.cn/open-apis/bot/v2/hook/1f0bb79e-bf26-4fb3-b122-fb6bc9e5d2bd
-#     '''
-#
-#     # content = __buildMsg(msgType=MSG_TYPE.IMAGE, content=uploadImage('face.png', getToken('cli_a36e2b4c87f1500d',
-#     #
-#     #                                                                                       'EctNmdDlhwEeEigAWFdp2eowutTFwz0v')))
-#
-#     setHookUrl('https://open.feishu.cn/open-apis/bot/v2/hook/1f0bb79e-bf26-4fb3-b122-fb6bc9e5d2bd')
-#     result = sendChatMsg(msgType=MSG_TYPE.IMAGE, content=uploadImage('face.png', getToken('cli_a36e2b4c87f1500d',
-#                                                                                           'EctNmdDlhwEeEigAWFdp2eowutTFwz0v')))
-#     if result[0]:
-#         print('发送成功')
-#     else:
-#         print('发送失败,' + result[1])
